# -*- coding: utf-8 -*-
"""build list of reacheble lslinks.xml files
"""

from tools import logger
log = logger.getLogger()

import lmglobals as GLM
import linkstructure

## from xml.etree.ElementTree import parse
from ElementTree import parse

def parseParameter(tree, tagName, argument='value', multiple=False):
    """parse one parameter from tree - if not exist or is empty, return None"""    
   
    log.debug("%s %s %s %s" % (tree, tagName, argument, multiple)  )
    
    #todo: recode it for right reading utf-8
    if multiple:
        value = []
        for tag in tree.findall(tagName):
            if tag != None:
                if len(tag.get(argument)) != 0:
                    value.append( tag.get(argument) )
                    
    else:            
        value = None
        #find one tag in tree
        tag = tree.find(tagName) 
        if tag != None:
           value = tag.get(argument)

    log.debug("%s" % (value)  )
    return value

def parseLSLinsksDirs(file):    
    """ parse lslinksdirs.xml file for info about directory to search links"""
    log.info("%s", file)
    dirs = []
    
    tree = parse(file)
    root = tree.getroot()
    
    for tag in root.findall('browsedir'):
        dirs.append( tag.get('path') )
        pass
    
    log.info("%s", dirs)
    return dirs        
    
def parseLinksFile(file):
    """ parse lslinks.xml files create instance of Link and put the parsed data into it"""
    log.debug("%s", file)
    links = []
    
    tree = parse(file)
    root = tree.getroot()
     
    # for every link subtree   
    for linkTag in root.findall('link'): 
        link = linkstructure.Link()
        parsedDataOk = True   # semaphor for data corruption


        # for all required params
        for parameter in GLM.reguiredLinkTags:
            value = parseParameter(linkTag, parameter)
            if value != None:
                #add parameter
                link.base[parameter] = value
            else: 
                parsedDataOk = False
                log.warning("Value of required parameter: %s in file %s is missing" % (parameter, file) )
                break
        if parsedDataOk == False:
            break  # skip to next link      

        
        #if required part was read successfully
        #for all optional params
        for parameter in GLM.optionalLinkTags:
            value = parseParameter(linkTag, parameter)
            if value != None:
                #add parameter
                link.base[parameter] = value
        
        #try to read description
        link.base['description'] = linkTag.findtext('description', 'None Description')
  
        #read groups informations
        groups = linkTag.find('groups')
        link.groups.extend( parseParameter(groups, 'group', 'name', True) )
       
  
        #add link to structure
        links = links + [link]
      
    log.debug("No. links: %s", len(links)  )
    return links

def parseGroupsFile(file):
    """ parse lsgroups.xml files create instance of group and put the parsed data into it"""
    log.debug("%s", file)
    groups = []
    
    tree = parse(file)
    root = tree.getroot()
     
    # for every group subtree   
    for groupTag in root.findall('group'): 
        group = linkstructure.Group()
        parsedDataOk = True   # semaphor for data corruption


        # for all required params
        for parameter in GLM.requiredGrupTags:
            value = parseParameter(groupTag, parameter)
            if value != None:
                #add parameter
                group.base[parameter] = value
            else: 
                parsedDataOk = False
                log.warning("Value of required parameter: %s in file %s is missing" % (parameter, file) )
                break
        if parsedDataOk == False:
            break  # skip to next subtree  

        
        #if required part was read successfully
        #for all optional params
        for parameter in GLM.optionalGroupTags:
            value = parseParameter(groupTag, parameter)
            if value != None:
                #add parameter
                if   value == 'False': group.base[parameter] = False
                elif value == 'True' : group.base[parameter] = True 
                else:                  group.base[parameter] = value
 
        #add link to structure
        groups = groups + [group]
      
    log.debug("No. groups: %s", len(groups)  )
    return groups 
